# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .state_service_pb2 import GetActiveContractsRequest, GetActiveContractsResponse, GetConnectedDomainsRequest, GetConnectedDomainsResponse, GetLatestPrunedOffsetsRequest, GetLatestPrunedOffsetsResponse, GetLedgerEndRequest, GetLedgerEndResponse

__all__ = [
    "StateServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class StateServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _StateServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _StateServiceAsyncStub: ...  # type: ignore
    def GetActiveContracts(self, __1: GetActiveContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[_grpc.CallIterator[GetActiveContractsResponse], _grpc_aio.UnaryStreamCall[_typing.Any, GetActiveContractsResponse]]: ...
    def GetConnectedDomains(self, __1: GetConnectedDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetConnectedDomainsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetConnectedDomainsResponse]]: ...
    def GetLedgerEnd(self, __1: GetLedgerEndRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetLedgerEndResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetLedgerEndResponse]]: ...
    def GetLatestPrunedOffsets(self, __1: GetLatestPrunedOffsetsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetLatestPrunedOffsetsResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetLatestPrunedOffsetsResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _StateServiceBlockingStub(StateServiceStub):
    def GetActiveContracts(self, __1: GetActiveContractsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GetActiveContractsResponse]: ...
    def GetConnectedDomains(self, __1: GetConnectedDomainsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConnectedDomainsResponse: ...
    def GetLedgerEnd(self, __1: GetLedgerEndRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLedgerEndResponse: ...
    def GetLatestPrunedOffsets(self, __1: GetLatestPrunedOffsetsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetLatestPrunedOffsetsResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _StateServiceAsyncStub(StateServiceStub):
    def GetActiveContracts(self, __1: GetActiveContractsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GetActiveContractsResponse]: ...  # type: ignore
    def GetConnectedDomains(self, __1: GetConnectedDomainsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetConnectedDomainsResponse]: ...  # type: ignore
    def GetLedgerEnd(self, __1: GetLedgerEndRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetLedgerEndResponse]: ...  # type: ignore
    def GetLatestPrunedOffsets(self, __1: GetLatestPrunedOffsetsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetLatestPrunedOffsetsResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/sequencer_administration_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/domain/admin/v0/sequencer_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/domain/admin/v0/sequencer_administration_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd3\x01\n\x15SequencerMemberStatus\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12?\n\rregistered_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0cregisteredAt\x12G\n\x11last_acknowledged\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10lastAcknowledged\x12\x18\n\x07\x65nabled\x18\x04 \x01(\x08R\x07\x65nabled\"\xf6\x01\n\x16SequencerPruningStatus\x12,\n\x03now\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x03now\x12T\n\x18\x65\x61rliest_event_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x16\x65\x61rliestEventTimestamp\x12X\n\x07members\x18\x03 \x03(\x0b\x32>.com.digitalasset.canton.domain.admin.v0.SequencerMemberStatusR\x07members2\x8a\x01\n\x1eSequencerAdministrationService\x12h\n\rPruningStatus\x12\x16.google.protobuf.Empty\x1a?.com.digitalasset.canton.domain.admin.v0.SequencerPruningStatusBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.sequencer_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_SEQUENCERMEMBERSTATUS']._serialized_start=186
  _globals['_SEQUENCERMEMBERSTATUS']._serialized_end=397
  _globals['_SEQUENCERPRUNINGSTATUS']._serialized_start=400
  _globals['_SEQUENCERPRUNINGSTATUS']._serialized_end=646
  _globals['_SEQUENCERADMINISTRATIONSERVICE']._serialized_start=649
  _globals['_SEQUENCERADMINISTRATIONSERVICE']._serialized_end=787
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/merkle.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/merkle.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0com/digitalasset/canton/protocol/v0/merkle.proto\x12#com.digitalasset.canton.protocol.v0\"\x8a\x03\n\x12GenTransactionTree\x12\x61\n\x12submitter_metadata\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x11submitterMetadata\x12[\n\x0f\x63ommon_metadata\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x0e\x63ommonMetadata\x12\x65\n\x14participant_metadata\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x13participantMetadata\x12M\n\nroot_views\x18\x04 \x01(\x0b\x32..com.digitalasset.canton.protocol.v0.MerkleSeqR\trootViews\"f\n\rBlindableNode\x12\x1e\n\tunblinded\x18\x01 \x01(\x0cH\x00R\tunblinded\x12#\n\x0c\x62linded_hash\x18\x02 \x01(\x0cH\x00R\x0b\x62lindedHashB\x10\n\x0e\x62linded_or_not\"c\n\tMerkleSeq\x12V\n\rroot_or_empty\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x0brootOrEmpty\"\xf0\x01\n\x10MerkleSeqElement\x12H\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x05\x66irst\x12J\n\x06second\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x06second\x12\x46\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.BlindableNodeR\x04\x64\x61taBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.merkle_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_GENTRANSACTIONTREE']._serialized_start=90
  _globals['_GENTRANSACTIONTREE']._serialized_end=484
  _globals['_BLINDABLENODE']._serialized_start=486
  _globals['_BLINDABLENODE']._serialized_end=588
  _globals['_MERKLESEQ']._serialized_start=590
  _globals['_MERKLESEQ']._serialized_end=689
  _globals['_MERKLESEQELEMENT']._serialized_start=692
  _globals['_MERKLESEQELEMENT']._serialized_end=932
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMeteringReportRequest(_message.Message):
    __slots__ = ("to", "application_id")
    FROM_FIELD_NUMBER: _ClassVar[int]
    TO_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    to: _timestamp_pb2.Timestamp
    application_id: str
    def __init__(self, to: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., application_id: _Optional[str] = ..., **kwargs) -> None: ...

class GetMeteringReportResponse(_message.Message):
    __slots__ = ("request", "report_generation_time", "metering_report_json")
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    REPORT_GENERATION_TIME_FIELD_NUMBER: _ClassVar[int]
    METERING_REPORT_JSON_FIELD_NUMBER: _ClassVar[int]
    request: GetMeteringReportRequest
    report_generation_time: _timestamp_pb2.Timestamp
    metering_report_json: _struct_pb2.Struct
    def __init__(self, request: _Optional[_Union[GetMeteringReportRequest, _Mapping]] = ..., report_generation_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., metering_report_json: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .sequencer_connection_service_pb2 import GetConnectionRequest, GetConnectionResponse, SetConnectionRequest, SetConnectionResponse

__all__ = [
    "SequencerConnectionServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class SequencerConnectionServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _SequencerConnectionServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _SequencerConnectionServiceAsyncStub: ...  # type: ignore
    def GetConnection(self, __1: GetConnectionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[GetConnectionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, GetConnectionResponse]]: ...
    def SetConnection(self, __1: SetConnectionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[SetConnectionResponse, _grpc_aio.UnaryUnaryCall[_typing.Any, SetConnectionResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerConnectionServiceBlockingStub(SequencerConnectionServiceStub):
    def GetConnection(self, __1: GetConnectionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> GetConnectionResponse: ...
    def SetConnection(self, __1: SetConnectionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> SetConnectionResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _SequencerConnectionServiceAsyncStub(SequencerConnectionServiceStub):
    def GetConnection(self, __1: GetConnectionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, GetConnectionResponse]: ...  # type: ignore
    def SetConnection(self, __1: SetConnectionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, SetConnectionResponse]: ...  # type: ignore



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import commands_pb2 as _commands_pb2
from . import interactive_submission_data_pb2 as _interactive_submission_data_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignatureFormat(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGNATURE_FORMAT_UNSPECIFIED: _ClassVar[SignatureFormat]
    SIGNATURE_FORMAT_RAW: _ClassVar[SignatureFormat]
SIGNATURE_FORMAT_UNSPECIFIED: SignatureFormat
SIGNATURE_FORMAT_RAW: SignatureFormat

class PrepareSubmissionRequest(_message.Message):
    __slots__ = ("application_id", "command_id", "commands", "min_ledger_time_abs", "min_ledger_time_rel", "act_as", "read_as", "disclosed_contracts", "domain_id", "package_id_selection_preference")
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    COMMAND_ID_FIELD_NUMBER: _ClassVar[int]
    COMMANDS_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_ABS_FIELD_NUMBER: _ClassVar[int]
    MIN_LEDGER_TIME_REL_FIELD_NUMBER: _ClassVar[int]
    ACT_AS_FIELD_NUMBER: _ClassVar[int]
    READ_AS_FIELD_NUMBER: _ClassVar[int]
    DISCLOSED_CONTRACTS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_ID_SELECTION_PREFERENCE_FIELD_NUMBER: _ClassVar[int]
    application_id: str
    command_id: str
    commands: _containers.RepeatedCompositeFieldContainer[_commands_pb2.Command]
    min_ledger_time_abs: _timestamp_pb2.Timestamp
    min_ledger_time_rel: _duration_pb2.Duration
    act_as: _containers.RepeatedScalarFieldContainer[str]
    read_as: _containers.RepeatedScalarFieldContainer[str]
    disclosed_contracts: _containers.RepeatedCompositeFieldContainer[_commands_pb2.DisclosedContract]
    domain_id: str
    package_id_selection_preference: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, application_id: _Optional[str] = ..., command_id: _Optional[str] = ..., commands: _Optional[_Iterable[_Union[_commands_pb2.Command, _Mapping]]] = ..., min_ledger_time_abs: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., min_ledger_time_rel: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., act_as: _Optional[_Iterable[str]] = ..., read_as: _Optional[_Iterable[str]] = ..., disclosed_contracts: _Optional[_Iterable[_Union[_commands_pb2.DisclosedContract, _Mapping]]] = ..., domain_id: _Optional[str] = ..., package_id_selection_preference: _Optional[_Iterable[str]] = ...) -> None: ...

class PrepareSubmissionResponse(_message.Message):
    __slots__ = ("prepared_transaction", "prepared_transaction_hash")
    PREPARED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PREPARED_TRANSACTION_HASH_FIELD_NUMBER: _ClassVar[int]
    prepared_transaction: _interactive_submission_data_pb2.PreparedTransaction
    prepared_transaction_hash: bytes
    def __init__(self, prepared_transaction: _Optional[_Union[_interactive_submission_data_pb2.PreparedTransaction, _Mapping]] = ..., prepared_transaction_hash: _Optional[bytes] = ...) -> None: ...

class Signature(_message.Message):
    __slots__ = ("format", "signature", "signed_by")
    FORMAT_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    SIGNED_BY_FIELD_NUMBER: _ClassVar[int]
    format: SignatureFormat
    signature: bytes
    signed_by: str
    def __init__(self, format: _Optional[_Union[SignatureFormat, str]] = ..., signature: _Optional[bytes] = ..., signed_by: _Optional[str] = ...) -> None: ...

class SinglePartySignatures(_message.Message):
    __slots__ = ("party", "signatures")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    party: str
    signatures: _containers.RepeatedCompositeFieldContainer[Signature]
    def __init__(self, party: _Optional[str] = ..., signatures: _Optional[_Iterable[_Union[Signature, _Mapping]]] = ...) -> None: ...

class PartySignatures(_message.Message):
    __slots__ = ("signatures",)
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedCompositeFieldContainer[SinglePartySignatures]
    def __init__(self, signatures: _Optional[_Iterable[_Union[SinglePartySignatures, _Mapping]]] = ...) -> None: ...

class ExecuteSubmissionRequest(_message.Message):
    __slots__ = ("prepared_transaction", "parties_signatures", "workflow_id", "deduplication_duration", "deduplication_offset", "submission_id", "application_id")
    PREPARED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    PARTIES_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_DURATION_FIELD_NUMBER: _ClassVar[int]
    DEDUPLICATION_OFFSET_FIELD_NUMBER: _ClassVar[int]
    SUBMISSION_ID_FIELD_NUMBER: _ClassVar[int]
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    prepared_transaction: _interactive_submission_data_pb2.PreparedTransaction
    parties_signatures: PartySignatures
    workflow_id: str
    deduplication_duration: _duration_pb2.Duration
    deduplication_offset: int
    submission_id: str
    application_id: str
    def __init__(self, prepared_transaction: _Optional[_Union[_interactive_submission_data_pb2.PreparedTransaction, _Mapping]] = ..., parties_signatures: _Optional[_Union[PartySignatures, _Mapping]] = ..., workflow_id: _Optional[str] = ..., deduplication_duration: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., deduplication_offset: _Optional[int] = ..., submission_id: _Optional[str] = ..., application_id: _Optional[str] = ...) -> None: ...

class ExecuteSubmissionResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

from .sequencer_authentication_service_pb2 import SequencerAuthentication
from .sequencer_authentication_service_pb2_grpc import SequencerAuthenticationServiceStub
from .sequencer_connect_service_pb2 import SequencerConnect
from .sequencer_connect_service_pb2_grpc import SequencerConnectServiceStub
from .sequencer_service_pb2 import AcknowledgeRequest, AcknowledgeResponse, AcknowledgeSignedRequest, AcknowledgeSignedResponse, DownloadTopologyStateForInitRequest, DownloadTopologyStateForInitResponse, GetTrafficStateForMemberRequest, GetTrafficStateForMemberResponse, SendAsyncVersionedRequest, SendAsyncVersionedResponse, SequencedEventTrafficState, SubscriptionRequest, TrafficControlErrorReason, VersionedSubscriptionResponse
from .sequencer_service_pb2_grpc import SequencerServiceStub

__all__ = [
    "AcknowledgeRequest",
    "AcknowledgeResponse",
    "AcknowledgeSignedRequest",
    "AcknowledgeSignedResponse",
    "DownloadTopologyStateForInitRequest",
    "DownloadTopologyStateForInitResponse",
    "GetTrafficStateForMemberRequest",
    "GetTrafficStateForMemberResponse",
    "SendAsyncVersionedRequest",
    "SendAsyncVersionedResponse",
    "SequencedEventTrafficState",
    "SequencerAuthentication",
    "SequencerAuthenticationServiceStub",
    "SequencerConnect",
    "SequencerConnectServiceStub",
    "SequencerServiceStub",
    "SubscriptionRequest",
    "TrafficControlErrorReason",
    "VersionedSubscriptionResponse",
]



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TrafficControlStateRequest(_message.Message):
    __slots__ = ("domain_id",)
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    def __init__(self, domain_id: _Optional[str] = ...) -> None: ...

class TrafficControlStateResponse(_message.Message):
    __slots__ = ("traffic_state",)
    TRAFFIC_STATE_FIELD_NUMBER: _ClassVar[int]
    traffic_state: TrafficState
    def __init__(self, traffic_state: _Optional[_Union[TrafficState, _Mapping]] = ...) -> None: ...

class TrafficState(_message.Message):
    __slots__ = ("extra_traffic_purchased", "extra_traffic_consumed", "base_traffic_remainder", "last_consumed_cost", "timestamp", "serial")
    EXTRA_TRAFFIC_PURCHASED_FIELD_NUMBER: _ClassVar[int]
    EXTRA_TRAFFIC_CONSUMED_FIELD_NUMBER: _ClassVar[int]
    BASE_TRAFFIC_REMAINDER_FIELD_NUMBER: _ClassVar[int]
    LAST_CONSUMED_COST_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    extra_traffic_purchased: int
    extra_traffic_consumed: int
    base_traffic_remainder: int
    last_consumed_cost: int
    timestamp: int
    serial: _wrappers_pb2.UInt32Value
    def __init__(self, extra_traffic_purchased: _Optional[int] = ..., extra_traffic_consumed: _Optional[int] = ..., base_traffic_remainder: _Optional[int] = ..., last_consumed_cost: _Optional[int] = ..., timestamp: _Optional[int] = ..., serial: _Optional[_Union[_wrappers_pb2.UInt32Value, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ....crypto.v0 import crypto_pb2 as _crypto_pb2
from ...api.v0 import sequencer_connection_pb2 as _sequencer_connection_pb2
from ....protocol.v0 import sequencing_pb2 as _sequencing_pb2
from ....protocol.v0 import topology_ext_pb2 as _topology_ext_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InitializeMediatorRequest(_message.Message):
    __slots__ = ("domain_id", "mediator_id", "current_identity_state", "domain_parameters", "sequencer_connection", "signing_key_fingerprint")
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_ID_FIELD_NUMBER: _ClassVar[int]
    CURRENT_IDENTITY_STATE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_FIELD_NUMBER: _ClassVar[int]
    SIGNING_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    domain_id: str
    mediator_id: str
    current_identity_state: _topology_ext_pb2.TopologyTransactions
    domain_parameters: _sequencing_pb2.StaticDomainParameters
    sequencer_connection: _sequencer_connection_pb2.SequencerConnection
    signing_key_fingerprint: _wrappers_pb2.StringValue
    def __init__(self, domain_id: _Optional[str] = ..., mediator_id: _Optional[str] = ..., current_identity_state: _Optional[_Union[_topology_ext_pb2.TopologyTransactions, _Mapping]] = ..., domain_parameters: _Optional[_Union[_sequencing_pb2.StaticDomainParameters, _Mapping]] = ..., sequencer_connection: _Optional[_Union[_sequencer_connection_pb2.SequencerConnection, _Mapping]] = ..., signing_key_fingerprint: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...

class InitializeMediatorResponse(_message.Message):
    __slots__ = ("success", "failure")
    class Success(_message.Message):
        __slots__ = ("mediator_key",)
        MEDIATOR_KEY_FIELD_NUMBER: _ClassVar[int]
        mediator_key: _crypto_pb2.SigningPublicKey
        def __init__(self, mediator_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ...) -> None: ...
    class Failure(_message.Message):
        __slots__ = ("reason",)
        REASON_FIELD_NUMBER: _ClassVar[int]
        reason: str
        def __init__(self, reason: _Optional[str] = ...) -> None: ...
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    FAILURE_FIELD_NUMBER: _ClassVar[int]
    success: InitializeMediatorResponse.Success
    failure: InitializeMediatorResponse.Failure
    def __init__(self, success: _Optional[_Union[InitializeMediatorResponse.Success, _Mapping]] = ..., failure: _Optional[_Union[InitializeMediatorResponse.Failure, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/time/admin/v30/domain_time_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/time/admin/v30/domain_time_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@com/digitalasset/canton/time/admin/v30/domain_time_service.proto\x12&com.digitalasset.canton.time.admin.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x91\x01\n\x10\x46\x65tchTimeRequest\x12\x39\n\tdomain_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x12\x42\n\x0f\x66reshness_bound\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0e\x66reshnessBound\"M\n\x11\x46\x65tchTimeResponse\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x87\x01\n\x10\x41waitTimeRequest\x12\x39\n\tdomain_id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x64omainId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x13\n\x11\x41waitTimeResponse2\x99\x02\n\x11\x44omainTimeService\x12\x80\x01\n\tFetchTime\x12\x38.com.digitalasset.canton.time.admin.v30.FetchTimeRequest\x1a\x39.com.digitalasset.canton.time.admin.v30.FetchTimeResponse\x12\x80\x01\n\tAwaitTime\x12\x38.com.digitalasset.canton.time.admin.v30.AwaitTimeRequest\x1a\x39.com.digitalasset.canton.time.admin.v30.AwaitTimeResponseBWZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/time/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.time.admin.v30.domain_time_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZUgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/time/admin/v30'
  _globals['_FETCHTIMEREQUEST']._serialized_start=206
  _globals['_FETCHTIMEREQUEST']._serialized_end=351
  _globals['_FETCHTIMERESPONSE']._serialized_start=353
  _globals['_FETCHTIMERESPONSE']._serialized_end=430
  _globals['_AWAITTIMEREQUEST']._serialized_start=433
  _globals['_AWAITTIMEREQUEST']._serialized_end=568
  _globals['_AWAITTIMERESPONSE']._serialized_start=570
  _globals['_AWAITTIMERESPONSE']._serialized_end=589
  _globals['_DOMAINTIMESERVICE']._serialized_start=592
  _globals['_DOMAINTIMESERVICE']._serialized_end=873
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/crypto/v0/crypto.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/crypto/v0/crypto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.com/digitalasset/canton/crypto/v0/crypto.proto\x12!com.digitalasset.canton.crypto.v0\"j\n\x04Hmac\x12N\n\talgorithm\x18\x01 \x01(\x0e\x32\x30.com.digitalasset.canton.crypto.v0.HmacAlgorithmR\talgorithm\x12\x12\n\x04hmac\x18\x02 \x01(\x0cR\x04hmac\"o\n\x04Salt\x12\x46\n\x04hmac\x18\x01 \x01(\x0e\x32\x30.com.digitalasset.canton.crypto.v0.HmacAlgorithmH\x00R\x04hmac\x12\x12\n\x04salt\x18\x02 \x01(\x0cR\x04saltB\x0b\n\talgorithm\"\x92\x01\n\tSignature\x12J\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\"\xe5\x01\n\tPublicKey\x12\x63\n\x12signing_public_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyH\x00R\x10signingPublicKey\x12l\n\x15\x65ncryption_public_key\x18\x02 \x01(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyH\x00R\x13\x65ncryptionPublicKeyB\x05\n\x03key\"t\n\x11PublicKeyWithName\x12K\n\npublic_key\x18\x01 \x01(\x0b\x32,.com.digitalasset.canton.crypto.v0.PublicKeyR\tpublicKey\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\"\xec\x01\n\nPrivateKey\x12\x66\n\x13signing_private_key\x18\x01 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.SigningPrivateKeyH\x00R\x11signingPrivateKey\x12o\n\x16\x65ncryption_private_key\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v0.EncryptionPrivateKeyH\x00R\x14\x65ncryptionPrivateKeyB\x05\n\x03key\"\xda\x01\n\x10SigningPublicKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12J\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x06\x66ormat\x12\x1d\n\npublic_key\x18\x03 \x01(\x0cR\tpublicKey\x12K\n\x06scheme\x18\x04 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v0.SigningKeySchemeR\x06scheme\"\xdd\x01\n\x11SigningPrivateKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12J\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x06\x66ormat\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12K\n\x06scheme\x18\x04 \x01(\x0e\x32\x33.com.digitalasset.canton.crypto.v0.SigningKeySchemeR\x06scheme\"\xbb\x01\n\x0eSigningKeyPair\x12R\n\npublic_key\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.crypto.v0.SigningPublicKeyR\tpublicKey\x12U\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.SigningPrivateKeyR\nprivateKey\"\xe0\x01\n\x13\x45ncryptionPublicKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12J\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x06\x66ormat\x12\x1d\n\npublic_key\x18\x03 \x01(\x0cR\tpublicKey\x12N\n\x06scheme\x18\x04 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionKeySchemeR\x06scheme\"\xe3\x01\n\x14\x45ncryptionPrivateKey\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12J\n\x06\x66ormat\x18\x02 \x01(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x06\x66ormat\x12\x1f\n\x0bprivate_key\x18\x03 \x01(\x0cR\nprivateKey\x12N\n\x06scheme\x18\x04 \x01(\x0e\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionKeySchemeR\x06scheme\"\xc4\x01\n\x11\x45ncryptionKeyPair\x12U\n\npublic_key\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.crypto.v0.EncryptionPublicKeyR\tpublicKey\x12X\n\x0bprivate_key\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v0.EncryptionPrivateKeyR\nprivateKey\"\xde\x01\n\rCryptoKeyPair\x12]\n\x10signing_key_pair\x18\x01 \x01(\x0b\x32\x31.com.digitalasset.canton.crypto.v0.SigningKeyPairH\x00R\x0esigningKeyPair\x12\x66\n\x13\x65ncryption_key_pair\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v0.EncryptionKeyPairH\x00R\x11\x65ncryptionKeyPairB\x06\n\x04pair\"\xbb\x01\n\x0cSymmetricKey\x12J\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x32.com.digitalasset.canton.crypto.v0.CryptoKeyFormatR\x06\x66ormat\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12M\n\x06scheme\x18\x03 \x01(\x0e\x32\x35.com.digitalasset.canton.crypto.v0.SymmetricKeySchemeR\x06scheme*5\n\rHashAlgorithm\x12\x18\n\x14MissingHashAlgorithm\x10\x00\x12\n\n\x06Sha256\x10\x01*9\n\rHmacAlgorithm\x12\x18\n\x14MissingHmacAlgorithm\x10\x00\x12\x0e\n\nHmacSha256\x10\x01*E\n\x0fSignatureFormat\x12\x1a\n\x16MissingSignatureFormat\x10\x00\x12\x16\n\x12RawSignatureFormat\x10\x01*T\n\nKeyPurpose\x12\x15\n\x11UnknownKeyPurpose\x10\x00\x12\x15\n\x11SigningKeyPurpose\x10\x01\x12\x18\n\x14\x45ncryptionKeyPurpose\x10\x02*c\n\x10SigningKeyScheme\x12\x1b\n\x17MissingSigningKeyScheme\x10\x00\x12\x0b\n\x07\x45\x64\x32\x35\x35\x31\x39\x10\x01\x12\r\n\tEcDsaP256\x10\x02\x12\r\n\tEcDsaP384\x10\x03\x12\x07\n\x03Sm2\x10\x04*\x94\x01\n\x13\x45ncryptionKeyScheme\x12\x1e\n\x1aMissingEncryptionKeyScheme\x10\x00\x12$\n EciesP256HkdfHmacSha256Aes128Gcm\x10\x01\x12 \n\x1c\x45\x63iesP256HmacSha256Aes128Cbc\x10\x02\x12\x15\n\x11Rsa2048OaepSha256\x10\x03*B\n\x12SymmetricKeyScheme\x12\x1d\n\x19MissingSymmetricKeyScheme\x10\x00\x12\r\n\tAes128Gcm\x10\x01*X\n\x0f\x43ryptoKeyFormat\x12\x1a\n\x16MissingCryptoKeyFormat\x10\x00\x12\x08\n\x04Tink\x10\x01\x12\x07\n\x03\x44\x65r\x10\x02\x12\x07\n\x03Raw\x10\x03\x12\r\n\x08Symbolic\x10\x90NBRZPgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.crypto.v0.crypto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZPgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/crypto/v0'
  _globals['_HASHALGORITHM']._serialized_start=2750
  _globals['_HASHALGORITHM']._serialized_end=2803
  _globals['_HMACALGORITHM']._serialized_start=2805
  _globals['_HMACALGORITHM']._serialized_end=2862
  _globals['_SIGNATUREFORMAT']._serialized_start=2864
  _globals['_SIGNATUREFORMAT']._serialized_end=2933
  _globals['_KEYPURPOSE']._serialized_start=2935
  _globals['_KEYPURPOSE']._serialized_end=3019
  _globals['_SIGNINGKEYSCHEME']._serialized_start=3021
  _globals['_SIGNINGKEYSCHEME']._serialized_end=3120
  _globals['_ENCRYPTIONKEYSCHEME']._serialized_start=3123
  _globals['_ENCRYPTIONKEYSCHEME']._serialized_end=3271
  _globals['_SYMMETRICKEYSCHEME']._serialized_start=3273
  _globals['_SYMMETRICKEYSCHEME']._serialized_end=3339
  _globals['_CRYPTOKEYFORMAT']._serialized_start=3341
  _globals['_CRYPTOKEYFORMAT']._serialized_end=3429
  _globals['_HMAC']._serialized_start=85
  _globals['_HMAC']._serialized_end=191
  _globals['_SALT']._serialized_start=193
  _globals['_SALT']._serialized_end=304
  _globals['_SIGNATURE']._serialized_start=307
  _globals['_SIGNATURE']._serialized_end=453
  _globals['_PUBLICKEY']._serialized_start=456
  _globals['_PUBLICKEY']._serialized_end=685
  _globals['_PUBLICKEYWITHNAME']._serialized_start=687
  _globals['_PUBLICKEYWITHNAME']._serialized_end=803
  _globals['_PRIVATEKEY']._serialized_start=806
  _globals['_PRIVATEKEY']._serialized_end=1042
  _globals['_SIGNINGPUBLICKEY']._serialized_start=1045
  _globals['_SIGNINGPUBLICKEY']._serialized_end=1263
  _globals['_SIGNINGPRIVATEKEY']._serialized_start=1266
  _globals['_SIGNINGPRIVATEKEY']._serialized_end=1487
  _globals['_SIGNINGKEYPAIR']._serialized_start=1490
  _globals['_SIGNINGKEYPAIR']._serialized_end=1677
  _globals['_ENCRYPTIONPUBLICKEY']._serialized_start=1680
  _globals['_ENCRYPTIONPUBLICKEY']._serialized_end=1904
  _globals['_ENCRYPTIONPRIVATEKEY']._serialized_start=1907
  _globals['_ENCRYPTIONPRIVATEKEY']._serialized_end=2134
  _globals['_ENCRYPTIONKEYPAIR']._serialized_start=2137
  _globals['_ENCRYPTIONKEYPAIR']._serialized_end=2333
  _globals['_CRYPTOKEYPAIR']._serialized_start=2336
  _globals['_CRYPTOKEYPAIR']._serialized_end=2558
  _globals['_SYMMETRICKEY']._serialized_start=2561
  _globals['_SYMMETRICKEY']._serialized_end=2748
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v1/participant_transfer.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v1/participant_transfer.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v0 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v0_dot_crypto__pb2
from ..v0 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_sequencing__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_common__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v1_dot_merkle__pb2
from ...time.v0 import time_proof_pb2 as com_dot_digitalasset_dot_canton_dot_time_dot_v0_dot_time__proof__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/protocol/v1/participant_transfer.proto\x12#com.digitalasset.canton.protocol.v1\x1a.com/digitalasset/canton/crypto/v0/crypto.proto\x1a\x34\x63om/digitalasset/canton/protocol/v0/sequencing.proto\x1a\x30\x63om/digitalasset/canton/protocol/v1/common.proto\x1a\x30\x63om/digitalasset/canton/protocol/v1/merkle.proto\x1a\x30\x63om/digitalasset/canton/time/v0/time_proof.proto\"\xb7\x02\n\x15TransferOutCommonData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12#\n\rsource_domain\x18\x02 \x01(\tR\x0csourceDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12#\n\radmin_parties\x18\x04 \x03(\tR\x0c\x61\x64minParties\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\'\n\x0fsource_mediator\x18\x06 \x01(\tR\x0esourceMediator\x12\x36\n\x17source_protocol_version\x18\x07 \x01(\x05R\x15sourceProtocolVersion\"\xc6\x01\n\x10TransferViewTree\x12S\n\x0b\x63ommon_data\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v1.BlindableNodeR\ncommonData\x12]\n\x10participant_data\x18\x02 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v1.BlindableNodeR\x0fparticipantData\"f\n\x19TransferInMediatorMessage\x12I\n\x04tree\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v1.TransferViewTreeR\x04tree\"g\n\x1aTransferOutMediatorMessage\x12I\n\x04tree\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v1.TransferViewTreeR\x04tree\"\xc2\x02\n\x0fTransferOutView\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x1f\n\x0b\x63ontract_id\x18\x03 \x01(\tR\ncontractId\x12#\n\rtarget_domain\x18\x04 \x01(\tR\x0ctargetDomain\x12V\n\x11target_time_proof\x18\x05 \x01(\x0b\x32*.com.digitalasset.canton.time.v0.TimeProofR\x0ftargetTimeProof\x12\x36\n\x17target_protocol_version\x18\x06 \x01(\x05R\x15targetProtocolVersion\"\x91\x02\n\x14TransferInCommonData\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12#\n\rtarget_domain\x18\x02 \x01(\tR\x0ctargetDomain\x12\"\n\x0cstakeholders\x18\x03 \x03(\tR\x0cstakeholders\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\'\n\x0ftarget_mediator\x18\x06 \x01(\tR\x0etargetMediator\x12\x36\n\x17target_protocol_version\x18\x07 \x01(\x05R\x15targetProtocolVersion\"\xa1\x03\n\x0eTransferInView\x12;\n\x04salt\x18\x01 \x01(\x0b\x32\'.com.digitalasset.canton.crypto.v0.SaltR\x04salt\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12U\n\x08\x63ontract\x18\x03 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v1.SerializableContractR\x08\x63ontract\x12m\n\x19transfer_out_result_event\x18\x04 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v0.SignedContentR\x16transferOutResultEvent\x12\x36\n\x17\x63reating_transaction_id\x18\x05 \x01(\x0cR\x15\x63reatingTransactionId\x12\x36\n\x17source_protocol_version\x18\x06 \x01(\x05R\x15sourceProtocolVersionBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v1.participant_transfer_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v1'
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_start=356
  _globals['_TRANSFEROUTCOMMONDATA']._serialized_end=667
  _globals['_TRANSFERVIEWTREE']._serialized_start=670
  _globals['_TRANSFERVIEWTREE']._serialized_end=868
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_start=870
  _globals['_TRANSFERINMEDIATORMESSAGE']._serialized_end=972
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_start=974
  _globals['_TRANSFEROUTMEDIATORMESSAGE']._serialized_end=1077
  _globals['_TRANSFEROUTVIEW']._serialized_start=1080
  _globals['_TRANSFEROUTVIEW']._serialized_end=1402
  _globals['_TRANSFERINCOMMONDATA']._serialized_start=1405
  _globals['_TRANSFERINCOMMONDATA']._serialized_end=1678
  _globals['_TRANSFERINVIEW']._serialized_start=1681
  _globals['_TRANSFERINVIEW']._serialized_end=2098
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/confirmation_response.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v30/confirmation_response.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@com/digitalasset/canton/protocol/v30/confirmation_response.proto\x12$com.digitalasset.canton.protocol.v30\x1a\x17google/rpc/status.proto\"\x9d\x02\n\x0cLocalVerdict\x12R\n\x04\x63ode\x18\x01 \x01(\x0e\x32>.com.digitalasset.canton.protocol.v30.LocalVerdict.VerdictCodeR\x04\x63ode\x12*\n\x06reason\x18\x02 \x01(\x0b\x32\x12.google.rpc.StatusR\x06reason\"\x8c\x01\n\x0bVerdictCode\x12\x1c\n\x18VERDICT_CODE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aVERDICT_CODE_LOCAL_APPROVE\x10\x01\x12\x1d\n\x19VERDICT_CODE_LOCAL_REJECT\x10\x02\x12 \n\x1cVERDICT_CODE_LOCAL_MALFORMED\x10\x03\"\xe8\x02\n\x14\x43onfirmationResponse\x12\x1d\n\nrequest_id\x18\x01 \x01(\x03R\trequestId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12W\n\rlocal_verdict\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.LocalVerdictR\x0clocalVerdict\x12\x1b\n\troot_hash\x18\x04 \x01(\x0cR\x08rootHash\x12-\n\x12\x63onfirming_parties\x18\x05 \x03(\tR\x11\x63onfirmingParties\x12\x1b\n\tdomain_id\x18\x06 \x01(\tR\x08\x64omainId\x12W\n\rview_position\x18\x07 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.ViewPositionR\x0cviewPosition\"`\n\x0cViewPosition\x12P\n\x08position\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.MerkleSeqIndexR\x08position\"+\n\x0eMerkleSeqIndex\x12\x19\n\x08is_right\x18\x01 \x03(\x08R\x07isRightBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.confirmation_response_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_LOCALVERDICT']._serialized_start=132
  _globals['_LOCALVERDICT']._serialized_end=417
  _globals['_LOCALVERDICT_VERDICTCODE']._serialized_start=277
  _globals['_LOCALVERDICT_VERDICTCODE']._serialized_end=417
  _globals['_CONFIRMATIONRESPONSE']._serialized_start=420
  _globals['_CONFIRMATIONRESPONSE']._serialized_end=780
  _globals['_VIEWPOSITION']._serialized_start=782
  _globals['_VIEWPOSITION']._serialized_end=878
  _globals['_MERKLESEQINDEX']._serialized_start=880
  _globals['_MERKLESEQINDEX']._serialized_end=923
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import ledger_sync_event_pb2 as _ledger_sync_event_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SubmissionTrackingData(_message.Message):
    __slots__ = ("transaction",)
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    transaction: TransactionSubmissionTrackingData
    def __init__(self, transaction: _Optional[_Union[TransactionSubmissionTrackingData, _Mapping]] = ...) -> None: ...

class TransactionSubmissionTrackingData(_message.Message):
    __slots__ = ("completion_info", "rejection_cause", "domain_id")
    class RejectionCause(_message.Message):
        __slots__ = ("timeout", "rejection_reason_template")
        TIMEOUT_FIELD_NUMBER: _ClassVar[int]
        REJECTION_REASON_TEMPLATE_FIELD_NUMBER: _ClassVar[int]
        timeout: _empty_pb2.Empty
        rejection_reason_template: _ledger_sync_event_pb2.CommandRejected.GrpcRejectionReasonTemplate
        def __init__(self, timeout: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., rejection_reason_template: _Optional[_Union[_ledger_sync_event_pb2.CommandRejected.GrpcRejectionReasonTemplate, _Mapping]] = ...) -> None: ...
    COMPLETION_INFO_FIELD_NUMBER: _ClassVar[int]
    REJECTION_CAUSE_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    completion_info: _ledger_sync_event_pb2.CompletionInfo
    rejection_cause: TransactionSubmissionTrackingData.RejectionCause
    domain_id: _wrappers_pb2.StringValue
    def __init__(self, completion_info: _Optional[_Union[_ledger_sync_event_pb2.CompletionInfo, _Mapping]] = ..., rejection_cause: _Optional[_Union[TransactionSubmissionTrackingData.RejectionCause, _Mapping]] = ..., domain_id: _Optional[_Union[_wrappers_pb2.StringValue, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/command_completion_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/daml/ledger/api/v2/command_completion_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import completion_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_completion__pb2
from . import offset_checkpoint_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_offset__checkpoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/daml/ledger/api/v2/command_completion_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\'com/daml/ledger/api/v2/completion.proto\x1a.com/daml/ledger/api/v2/offset_checkpoint.proto\"\x83\x01\n\x17\x43ompletionStreamRequest\x12%\n\x0e\x61pplication_id\x18\x01 \x01(\tR\rapplicationId\x12\x18\n\x07parties\x18\x02 \x03(\tR\x07parties\x12\'\n\x0f\x62\x65gin_exclusive\x18\x03 \x01(\x03R\x0e\x62\x65ginExclusive\"\xd0\x01\n\x18\x43ompletionStreamResponse\x12\x44\n\ncompletion\x18\x01 \x01(\x0b\x32\".com.daml.ledger.api.v2.CompletionH\x00R\ncompletion\x12W\n\x11offset_checkpoint\x18\x02 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpointB\x15\n\x13\x63ompletion_response2\x93\x01\n\x18\x43ommandCompletionService\x12w\n\x10\x43ompletionStream\x12/.com.daml.ledger.api.v2.CompletionStreamRequest\x1a\x30.com.daml.ledger.api.v2.CompletionStreamResponse0\x01\x42\x9c\x01\n\x16\x63om.daml.ledger.api.v2B\"CommandCompletionServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.command_completion_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\"CommandCompletionServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_COMPLETIONSTREAMREQUEST']._serialized_start=173
  _globals['_COMPLETIONSTREAMREQUEST']._serialized_end=304
  _globals['_COMPLETIONSTREAMRESPONSE']._serialized_start=307
  _globals['_COMPLETIONSTREAMRESPONSE']._serialized_end=515
  _globals['_COMMANDCOMPLETIONSERVICE']._serialized_start=518
  _globals['_COMMANDCOMPLETIONSERVICE']._serialized_end=665
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import base64
import json
import sys
from typing import Callable, Literal, Optional, Union, final

from ..prim import Parties

if sys.version_info >= (3, 11):
    from typing import TypeAlias
else:
    from typing_extensions import TypeAlias

__all__ = [
    "TokenOrTokenProvider",
    "V1TokenNamespace",
    "get_token",
    "parse_token",
    "ParsedToken",
    "ParsedV1Token",
    "ParsedV2Token",
]

TokenOrTokenProvider: TypeAlias = Union[str, Callable[[], Union[Optional[str]]]]


V1TokenNamespace = "https://daml.com/ledger-api"
V2Scope = "daml_ledger_api"


@final
class ParsedV1Token:
    """
    Salient fields from a token used by Daml 1.
    """

    @property
    def token_version(self) -> Literal[1]:
        """
        Always returns "1".
        """
        return 1

    def __init__(
        self,
        read_as: Optional[Parties] = None,
        act_as: Optional[Parties] = None,
        admin: Optional[bool] = None,
        ledger_id: Optional[str] = None,
        application_name: Optional[str] = None,
    ) -> None:
        self.read_as = read_as
        self.act_as = act_as
        self.admin = admin
        self.ledger_id = ledger_id
        self.application_name = application_name

    read_as: Optional[Parties]
    act_as: Optional[Parties]
    admin: Optional[bool]
    ledger_id: Optional[str]
    application_name: Optional[str]


@final
class ParsedV2Token:
    """
    Salient fields from a token used by Daml 2 and later.
    """

    @property
    def token_version(self) -> Literal[2]:
        """
        Always returns "2".
        """
        return 2

    def __init__(self, user_id: str) -> None:
        self.user_id = user_id


ParsedToken = Union[ParsedV1Token, ParsedV2Token]


def get_token(t: Optional[TokenOrTokenProvider], /) -> Optional[str]:
    """
    Get a token.

    :param t:
        Either:
         - None
         - a string that is a valid Daml JWT
         - a function that returns a valid Daml JWT, or None
    :return:
        A Daml JWT if one could be returned or None.
    :exception TypeError:
        raised if an unknown type is passed in, or returned from the function
    """
    if t is None:
        return None
    elif isinstance(t, str):
        return t
    elif callable(t):
        r = t()
        if r is None:
            return None
        elif isinstance(r, str):
            return r
        else:
            raise TypeError(f"a token provider function returned an invalid type: {type(r)}")
    else:
        raise TypeError(f"invalid type of a token provider: {type(t)}")


def parse_token(t: str, /) -> ParsedToken:
    components = t.split(".", 3)
    if len(components) != 3:
        raise ValueError("not a JWT")

    pad_bytes = "=" * (-len(components[1]) % 4)
    claim_str = base64.urlsafe_b64decode(components[1] + pad_bytes)
    claims = json.loads(claim_str)

    has_v2_scope_marker = V2Scope in claims.get("scope", "").split(" ")
    v1_claims = claims.get(V1TokenNamespace)

    if has_v2_scope_marker:
        # "scope": "daml_ledger_api" definitely marks this as a Daml v2 token;
        # the absence of the v1 namespace also marks this as a token that
        # Daml v2 and later ledgers understand
        user_id = claims.get("sub")
        if user_id is None:
            raise ValueError("sub is a required field in a Daml token")
        return ParsedV2Token(user_id)
    elif v1_claims is not None:
        # we found Daml V1 claims, so assume it's a Daml V1 token
        return ParsedV1Token(
            read_as=frozenset(v1_claims.get("readAs", ())),
            act_as=frozenset(v1_claims.get("actAs", ())),
            admin=bool(v1_claims.get("admin", False)),
            ledger_id=v1_claims.get("ledgerId", None),
            application_name=v1_claims.get("applicationId", None),
        )
    else:
        user_id = claims.get("sub")
        if user_id is None:
            raise ValueError("sub is a required field in a Daml token")
        return ParsedV2Token(user_id)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcom/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\"\xf5\x02\n\x1bGenerateTransactionsRequest\x12n\n\tproposals\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest.ProposalR\tproposals\x1a\xe5\x01\n\x08Proposal\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\x12\x14\n\x05store\x18\x04 \x01(\tR\x05store\"\xaf\x02\n\x1cGenerateTransactionsResponse\x12\x94\x01\n\x16generated_transactions\x18\x01 \x03(\x0b\x32].com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponse.GeneratedTransactionR\x15generatedTransactions\x1ax\n\x14GeneratedTransaction\x12\x35\n\x16serialized_transaction\x18\x01 \x01(\x0cR\x15serializedTransaction\x12)\n\x10transaction_hash\x18\x02 \x01(\x0cR\x0ftransactionHash\"\xb9\x04\n\x10\x41uthorizeRequest\x12\x63\n\x08proposal\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest.ProposalH\x00R\x08proposal\x12+\n\x10transaction_hash\x18\x02 \x01(\tH\x00R\x0ftransactionHash\x12\x30\n\x14must_fully_authorize\x18\x03 \x01(\x08R\x12mustFullyAuthorize\x12Z\n\rforce_changes\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12\x1b\n\tsigned_by\x18\x05 \x03(\tR\x08signedBy\x12\x14\n\x05store\x18\x06 \x01(\tR\x05store\x1a\xc9\x01\n\x08Proposal\x12T\n\x06\x63hange\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\x06\x63hange\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mappingB\x06\n\x04type\"v\n\x11\x41uthorizeResponse\x12\x61\n\x0btransaction\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0btransaction\"\xef\x01\n\x16\x41\x64\x64TransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12Z\n\rforce_changes\x18\x02 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12\x14\n\x05store\x18\x03 \x01(\tR\x05store\"\x19\n\x17\x41\x64\x64TransactionsResponse\"b\n\x1dImportTopologySnapshotRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12\x14\n\x05store\x18\x02 \x01(\tR\x05store\" \n\x1eImportTopologySnapshotResponse\"\x9b\x01\n\x17SignTransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12\x1b\n\tsigned_by\x18\x02 \x03(\tR\x08signedBy\"\x7f\n\x18SignTransactionsResponse\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions*\x7f\n\tForceFlag\x12\x1a\n\x16\x46ORCE_FLAG_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x46ORCE_FLAG_ALIEN_MEMBER\x10\x01\x12\x39\n5FORCE_FLAG_LEDGER_TIME_RECORD_TIME_TOLERANCE_INCREASE\x10\x02\x32\xc3\x06\n\x1bTopologyManagerWriteService\x12\x88\x01\n\tAuthorize\x12<.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest\x1a=.com.digitalasset.canton.topology.admin.v30.AuthorizeResponse\x12\x9a\x01\n\x0f\x41\x64\x64Transactions\x12\x42.com.digitalasset.canton.topology.admin.v30.AddTransactionsRequest\x1a\x43.com.digitalasset.canton.topology.admin.v30.AddTransactionsResponse\x12\xaf\x01\n\x16ImportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotResponse\x12\x9d\x01\n\x10SignTransactions\x12\x43.com.digitalasset.canton.topology.admin.v30.SignTransactionsRequest\x1a\x44.com.digitalasset.canton.topology.admin.v30.SignTransactionsResponse\x12\xa9\x01\n\x14GenerateTransactions\x12G.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest\x1aH.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_write_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_FORCEFLAG']._serialized_start=2244
  _globals['_FORCEFLAG']._serialized_end=2371
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_start=181
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_end=554
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_start=325
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_end=554
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_start=557
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_end=860
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_start=740
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_end=860
  _globals['_AUTHORIZEREQUEST']._serialized_start=863
  _globals['_AUTHORIZEREQUEST']._serialized_end=1432
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_start=1223
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_end=1424
  _globals['_AUTHORIZERESPONSE']._serialized_start=1434
  _globals['_AUTHORIZERESPONSE']._serialized_end=1552
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_start=1555
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_end=1794
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_start=1796
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_end=1821
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=1823
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=1921
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=1923
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=1955
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_start=1958
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_end=2113
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_start=2115
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_end=2242
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_start=2374
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_end=3209
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v0/causality.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'com/digitalasset/canton/protocol/v0/causality.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import participant_transfer_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v0_dot_participant__transfer__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3com/digitalasset/canton/protocol/v0/causality.proto\x12#com.digitalasset.canton.protocol.v0\x1a>com/digitalasset/canton/protocol/v0/participant_transfer.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd6\x01\n\x10\x43\x61usalityMessage\x12(\n\x10target_domain_id\x18\x01 \x01(\tR\x0etargetDomainId\x12P\n\x0btransfer_id\x18\x02 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\ntransferId\x12\x46\n\x05\x63lock\x18\x03 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v0.VectorClockR\x05\x63lock\"\xb2\x02\n\x0bVectorClock\x12(\n\x10origin_domain_id\x18\x01 \x01(\tR\x0eoriginDomainId\x12\x35\n\x08local_ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07localTs\x12\x19\n\x08party_id\x18\x04 \x01(\tR\x07partyId\x12Q\n\x05\x63lock\x18\x05 \x03(\x0b\x32;.com.digitalasset.canton.protocol.v0.VectorClock.ClockEntryR\x05\x63lock\x1aT\n\nClockEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05value:\x02\x38\x01\"\xf3\x03\n\x0f\x43\x61usalityUpdate\x12\x32\n\x14informeeStakeholders\x18\x01 \x03(\tR\x14informeeStakeholders\x12*\n\x02ts\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x02ts\x12\x1b\n\tdomain_id\x18\x03 \x01(\tR\x08\x64omainId\x12\'\n\x0frequest_counter\x18\x04 \x01(\x03R\x0erequestCounter\x12\x66\n\x11transactionUpdate\x18\x05 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.TransactionUpdateH\x00R\x11transactionUpdate\x12\x66\n\x11transferOutUpdate\x18\x06 \x01(\x0b\x32\x36.com.digitalasset.canton.protocol.v0.TransferOutUpdateH\x00R\x11transferOutUpdate\x12\x63\n\x10transferInUpdate\x18\x07 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v0.TransferInUpdateH\x00R\x10transferInUpdateB\x05\n\x03tag\"\x13\n\x11TransactionUpdate\"e\n\x11TransferOutUpdate\x12P\n\x0btransfer_id\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\ntransferId\"d\n\x10TransferInUpdate\x12P\n\x0btransfer_id\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.protocol.v0.TransferIdR\ntransferIdBTZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v0.causality_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZRgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v0'
  _globals['_VECTORCLOCK_CLOCKENTRY']._loaded_options = None
  _globals['_VECTORCLOCK_CLOCKENTRY']._serialized_options = b'8\001'
  _globals['_CAUSALITYMESSAGE']._serialized_start=190
  _globals['_CAUSALITYMESSAGE']._serialized_end=404
  _globals['_VECTORCLOCK']._serialized_start=407
  _globals['_VECTORCLOCK']._serialized_end=713
  _globals['_VECTORCLOCK_CLOCKENTRY']._serialized_start=629
  _globals['_VECTORCLOCK_CLOCKENTRY']._serialized_end=713
  _globals['_CAUSALITYUPDATE']._serialized_start=716
  _globals['_CAUSALITYUPDATE']._serialized_end=1215
  _globals['_TRANSACTIONUPDATE']._serialized_start=1217
  _globals['_TRANSACTIONUPDATE']._serialized_end=1236
  _globals['_TRANSFEROUTUPDATE']._serialized_start=1238
  _globals['_TRANSFEROUTUPDATE']._serialized_end=1339
  _globals['_TRANSFERINUPDATE']._serialized_start=1341
  _globals['_TRANSFERINUPDATE']._serialized_end=1441
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import completion_pb2 as _completion_pb2
from . import offset_checkpoint_pb2 as _offset_checkpoint_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CompletionStreamRequest(_message.Message):
    __slots__ = ("application_id", "parties", "begin_exclusive")
    APPLICATION_ID_FIELD_NUMBER: _ClassVar[int]
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    BEGIN_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
    application_id: str
    parties: _containers.RepeatedScalarFieldContainer[str]
    begin_exclusive: int
    def __init__(self, application_id: _Optional[str] = ..., parties: _Optional[_Iterable[str]] = ..., begin_exclusive: _Optional[int] = ...) -> None: ...

class CompletionStreamResponse(_message.Message):
    __slots__ = ("completion", "offset_checkpoint")
    COMPLETION_FIELD_NUMBER: _ClassVar[int]
    OFFSET_CHECKPOINT_FIELD_NUMBER: _ClassVar[int]
    completion: _completion_pb2.Completion
    offset_checkpoint: _offset_checkpoint_pb2.OffsetCheckpoint
    def __init__(self, completion: _Optional[_Union[_completion_pb2.Completion, _Mapping]] = ..., offset_checkpoint: _Optional[_Union[_offset_checkpoint_pb2.OffsetCheckpoint, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0

from __future__ import annotations

import abc
from datetime import datetime
import sys
from typing import (
    TYPE_CHECKING,
    AbstractSet,
    Any,
    Collection,
    Final,
    Mapping,
    NoReturn,
    Optional,
    Sequence,
    Union,
    final,
)
import uuid

from .. import _repr
from ..damlast.daml_lf_1 import TypeConName
from ..damlast.lookup import parse_type_con_name
from ..prim import LEDGER_STRING_REGEX, ContractData, ContractId, Parties, Party, to_parties
from ..util.typing import safe_cast

if sys.version_info >= (3, 12):
    from typing import TypeAlias, TypeGuard
elif sys.version_info >= (3, 10):
    from typing import TypeGuard

    from typing_extensions import TypeAlias
else:
    from typing_extensions import TypeAlias, TypeGuard


__all__ = [
    "is_command",
    "to_commands",
    "ActAs",
    "Admin",
    "ArchiveEvent",
    "Boundary",
    "Command",
    "CommandMeta",
    "Commands",
    "CreateAndExerciseCommand",
    "CreateCommand",
    "CreateEvent",
    "Event",
    "EventOrBoundary",
    "ExerciseByKeyCommand",
    "ExerciseCommand",
    "ExerciseResponse",
    "IdentityProviderAdmin",
    "InterfaceView",
    "MeteringReport",
    "MeteringReportApplication",
    "MeteringReportRequest",
    "PartyInfo",
    "ReadAs",
    "Right",
    "SubmitResponse",
    "User",
    "Version",
    "VersionFeatures",
    "VersionUserManagementFeature",
]


def is_command(obj: Any, /) -> TypeGuard[Command]:
    """
    Determine whether an object is a :class:`Command`.

    This function is equivalent to calling ``isinstance(obj, Command)``. If you are using
    Python 3.10 or later, ``isinstance(obj, Command)`` should be preferred, but on Python 3.8 and 3.9,
    ``isinstance(obj, Command)`` will fail to typecheck due to ``Union`` not being understood as a
    valid argument. If your code must be compatible with Python 3.8 and 3.9 _and_ you wish to use a
    typechecker, use this convenience function instead.
    """
    return isinstance(obj, _Command)


def to_commands(*commands: Optional[Commands]) -> Sequence[Command]:
    cmds = list[Command]()
    if commands is not None:
        for c in commands:
            if c is not None:
                if is_command(c):
                    cmds.append(c)
                else:
                    cmds.extend(to_commands(*c))  # type: ignore
    return cmds


class _Command:
    """
    Base class for write-side commands.

    This class provides no functionality on its own.
    """

    def __setattr__(self, key, value) -> NoReturn:
        """
        Raise :class:`AttributeError`; instances of this class are immutable.
        """
        raise AttributeError("Command instances are read-only")


@final
class CreateCommand(_Command):
    """
    A command that creates a contract without any predecessors.

    Attributes:
    - template_id: The template of the contract to be created.
    - payload: The template arguments for the contract to be created.
    """

    __slots__ = ("template_id", "payload")
    __match_args__ = ("template_id", "payload")
    template_id: Final[TypeConName]  # type: ignore
    payload: Final[ContractData]  # type: ignore

    def __init__(self, template_id: Union[str, TypeConName], payload: ContractData):
        """
        Initialize a :class:`CreateCommand`.

        :param template_id:
            The template of the contract to be created.
        :param payload:
            The template arguments for the contract to be created.
        """
        object.__setattr__(self, "template_id", validate_template_id(template_id))
        object.__setattr__(self, "payload", payload)

    def __eq__(self, other: Any, /) -> bool:
        return (
            isinstance(other, CreateCommand)
            and self.template_id == other.template_id
            and self.payload == other.payload
        )

    def __repr__(self) -> str:
        return f"CreateCommand({self.template_id}, {self.payload})"


@final
class CreateAndExerciseCommand(_Command):
    """
    A command that exercises a choice on a newly-created contract in a single transaction.

    Instead of creating an instance of this command and submitting it with :meth:`Connection.submit`,
    consider using :meth:`Connection.create_and_exercise` instead, which also gives you access to
    the result of exercising the choice.

    Attributes:
    - template_id: The template of the contract to be created.
    - payload: The template arguments for the contract to be created.
    - choice: The choice to exercise.
    - argument: The choice arguments. Can be omitted for choices that take no arguments.
    """

    __slots__ = ("template_id", "payload", "choice", "argument")
    __match_args__ = ("template_id", "payload", "choice", "argument")
    template_id: Final[TypeConName]  # type: ignore
    payload: Final[ContractData]  # type: ignore
    choice: Final[str]  # type: ignore
    argument: Final[Any]  # type: ignore

    def __init__(
        self,
        template_id: Union[str, TypeConName],
        payload: ContractData,
        choice: str,
        argument: Optional[Any] = None,
    ):
        """
        Initialize a :class:`CreateAndExerciseCommand`.

        :param template_id:
            The template of the contract to be created.
        :param payload:
            The template arguments for the contract to be created.
        :param choice:
            The choice to exercise.
        :param argument:
            The choice arguments. Can be omitted for choices that take no arguments.
        """
        object.__setattr__(self, "template_id", validate_template_id(template_id))
        object.__setattr__(self, "payload", payload)
        object.__setattr__(self, "choice", choice)
        object.__setattr__(self, "argument", dict(argument) if argument is not None else dict())

    def __eq__(self, other: Any) -> bool:
        return (
            isinstance(other, CreateAndExerciseCommand)
            and self.template_id == other.template_id
            and self.payload == other.payload
            and self.choice == other.choice
            and self.argument == other.argument
        )

    def __repr__(self) -> str:
        return f"CreateAndExerciseCommand({self.template_id}, {self.payload}, {self.choice!r}, {self.argument})"


@final
class ExerciseCommand(_Command):
    """
    A command that exercises a choice on a contract identified by its contract ID.

    Instead of creating an instance of this command and submitting it with :meth:`Connection.submit`,
    consider using :meth:`Connection.exercise` instead, which also gives you access to the result of
    exercising the choice.
    """

    __slots__ = ("contract_id", "choice", "argument")
    __match_args__ = ("contract_id", "choice", "argument")
    contract_id: Final[ContractId]  # type: ignore
    choice: Final[str]  # type: ignore
    argument: Final[Any]  # type: ignore

    def __init__(self, contract_id: ContractId, choice: str, argument: Optional[Any] = None):
        """
        Initialize an :class:`ExerciseCommand`.

        :param contract_id:
            The contract ID of the contract to exercise.
        :param choice:
            The choice to exercise.
        :param argument:
            The choice arguments. Can be omitted for choices that take no arguments.
        """
        object.__setattr__(self, "contract_id", safe_cast(ContractId, contract_id))
        object.__setattr__(self, "choice", safe_cast(str, choice))
        object.__setattr__(self, "argument", dict(argument) if argument is not None else dict())

    def __eq__(self, other: Any) -> bool:
        return (
            isinstance(other, ExerciseCommand)
            and self.contract_id == other.contract_id
            and self.choice == other.choice
            and self.argument == other.argument
        )

    def __repr__(self):
        return f"ExerciseCommand({self.contract_id}, {self.choice!r}, {self.argument})"


@final
class ExerciseByKeyCommand(_Command):
    """
    A command that exercises a choice on a contract identified by its contract key.

    Instead of creating an instance of this command and submitting it with :meth:`Connection.submit`,
    consider using :meth:`Connection.exercise_by_key` instead, which also gives you access to the
    result of exercising the choice.
    """

    __slots__ = ("template_id", "key", "choice", "argument")
    __match_args__ = ("template_id", "key", "choice", "argument")
    template_id: TypeConName
    key: Any
    choice: str
    argument: Optional[Any]

    def __init__(
        self,
        template_id: Union[str, TypeConName],
        key: Any,
        choice: str,
        argument: Optional[Any] = None,
    ):
        """
        Initialize an :class:`ExerciseByKeyCommand`.

        :param template_id:
            The contract template type.
        :param key:
            The contract key of the contract to exercise.
        :param choice:
            The choice to exercise.
        :param argument:
            The choice arguments. Can be omitted for choices that take no arguments.
        """
        object.__setattr__(self, "template_id", validate_template_id(template_id))
        object.__setattr__(self, "key", key)
        object.__setattr__(self, "choice", choice)
        object.__setattr__(self, "argument", dict(argument) if argument is not None else dict())

    def __eq__(self, other: Any) -> bool:
        return (
            isinstance(other, ExerciseByKeyCommand)
            and self.template_id == other.template_id
            and self.key == other.key
            and self.choice == other.choice
            and self.argument == other.argument
        )

    def __repr__(self):
        return f"ExerciseByKeyCommand({self.template_id}, {self.key}, {self.choice!r}, {self.argument})"


if TYPE_CHECKING:
    # export Command as a union type so that exhaustive type checking can be performed
    # in Python 3.8 and Python 3.9, Union types are not allowed to be used for isinstance checks,
    # so the is_command convenience function should be used instead.
    if sys.version_info >= (3, 10):
        Command: TypeAlias = (
            CreateCommand | ExerciseCommand | CreateAndExerciseCommand | ExerciseByKeyCommand
        )
    else:
        Command: TypeAlias = Union[
            CreateCommand, ExerciseCommand, CreateAndExerciseCommand, ExerciseByKeyCommand
        ]
else:
    # export Command as an actual type so that isinstance checks can be performed
    Command = _Command


Commands: TypeAlias = Union[Command, Sequence[Command]]


class CommandMeta:
    """
    Additional fields that accompany a command submission.

    .. py:attribute:: workflow_id
        :type: str | None

        An optional workflow ID.

    .. py:attribute:: command_id
        :type: str | None

        An optional command ID. If unspecified, a random one will be created.

    .. py:attribute:: read_as
        :type: Collection[Party] | None

        An optional set of read-as parties to use to submit this command. Note that for a
        ledger with authorization, these parties must be a subset of the parties in the token.

    .. py:attribute:: act_as
        :type: Collection[Party] | None

        An optional set of act-as parties to use to submit this command. Note that for a
        ledger with authorization, these parties must be a subset of the parties in the token.
    """

    __slots__ = "workflow_id", "command_id", "read_as", "act_as", "user_id"

    workflow_id: Optional[str]
    command_id: Optional[str]
    read_as: Optional[Sequence[Party]]
    act_as: Optional[Sequence[Party]]
    user_id: str

    def __init__(
        self,
        workflow_id: Optional[str],
        command_id: Optional[str],
        read_as: Optional[Parties],
        act_as: Optional[Parties],
        user_id: str,
    ):
        if workflow_id:
            if not LEDGER_STRING_REGEX.match(workflow_id):
                raise ValueError("workflow_id must be a valid ledger string")
        else:
            workflow_id = None

        if command_id:
            if not LEDGER_STRING_REGEX.match(command_id):
                raise ValueError("command_id must be a valid ledger string")
        else:
            command_id = uuid.uuid4().hex

        object.__setattr__(self, "workflow_id", workflow_id)
        object.__setattr__(self, "command_id", command_id)
        object.__setattr__(self, "read_as", to_parties(read_as))
        object.__setattr__(self, "act_as", to_parties(act_as))
        object.__setattr__(self, "user_id", user_id)

    @property
    def application_name(self) -> str:
        return self.user_id

    def __eq__(self, other: Any) -> bool:
        return (
            isinstance(other, CommandMeta)
            and self.workflow_id == other.workflow_id
            and self.command_id == other.command_id
            and self.read_as == other.read_as
            and self.act_as == other.act_as
        )

    def __repr__(self) -> str:
        s = []
        if self.workflow_id is not None:
            s.append(f"workflow_id={_repr.str(self.workflow_id)}")
        if self.command_id is not None:
            s.append(f"command_id={_repr.str(self.command_id )}")
        if self.read_as is not None:
            s.append(f"read_as={_repr.list(self.read_as)}")
        if self.act_as is not None:
            s.append(f"act_as={_repr.list(self.act_as)}")
        return f"{self.__class__.__name__}({', '.join(s)})"


class CreateEvent:
    """
    An event that indicates a newly-created contract.
    """

    __slots__ = (
        "_contract_id",
        "_payload",
        "_signatories",
        "_observers",
        "_agreement_text",
        "_key",
        "_created_event_blob",
        "_interface_views",
    )
    if TYPE_CHECKING:
        _contract_id: ContractId
        _payload: ContractData
        _signatories: AbstractSet[Party]
        _observers: AbstractSet[Party]
        _agreement_text: Optional[str]
        _key: Optional[Any]
        _created_event_blob: Optional[bytes]
        _interface_views: Sequence[InterfaceView]

    def __init__(
        self,
        contract_id: ContractId,
        payload: ContractData,
        signatories: Collection[Party],
        observers: Collection[Party],
        agreement_text: Optional[str],
        key: Optional[Any],
        created_event_blob: Optional[bytes] = None,
        interface_views: Sequence[InterfaceView] = (),
    ):
        object.__setattr__(self, "_contract_id", contract_id)
        object.__setattr__(self, "_payload", payload)
        object.__setattr__(self, "_signatories", frozenset(signatories))
        object.__setattr__(self, "_observers", frozenset(observers))
        object.__setattr__(self, "_agreement_text", agreement_text)
        object.__setattr__(self, "_key", key)
        object.__setattr__(self, "_created_event_blob", created_event_blob)
        object.__setattr__(self, "_interface_views", tuple(interface_views))

    @property
    def contract_id(self) -> ContractId:
        """
        The ID of the created contract.
        """
        return self._contract_id

    @property
    def payload(self) -> ContractData:
        """
        The `parameters <https://docs.daml.com/daml/reference/templates.html#template-parameters>`_
        that were used to create the contract.
        """
        return self._payload

    @property
    def signatories(self) -> AbstractSet[Party]:
        """
        The `signatories <https://docs.daml.com/daml/reference/templates.html#signatory-parties>`_
        for this contract as specified by the template.
        """
        return self._signatories

    @property
    def observers(self) -> AbstractSet[Party]:
        """
        The `observers <https://docs.daml.com/daml/reference/templates.html#observers>`_ for this
        contract as specified explicitly by the template or implicitly as choice controllers.
        """
        return self._observers

    @property
    def agreement_text(self) -> Optional[str]:
        """
        The `agreement text <https://docs.daml.com/daml/reference/templates.html#agreements>`_ of
        the contract.
        """
        return self._agreement_text

    @property
    def key(self) -> Optional[Any]:
        """
        The `key <https://docs.daml.com/daml/reference/templates.html#contract-keys-and-maintainers>`_
        of the contract, if defined.
        """
        return self._key

    @property
    def created_event_blob(self) -> Optional[bytes]:
        """
        Opaque representation of contract create event payload intended for
        forwarding to an API server as a contract disclosed as part of a
        command submission.
        """
        return self._created_event_blob

    @property
    def interface_views(self) -> Sequence[InterfaceView]:
        """
        Interface views specified in the transaction filter.
        Includes an :class:`InterfaceView` for each interface for which there
        is an interface filter.
        """
        return self._interface_views

    def __eq__(self, other: Any) -> bool:
        return (
            isinstance(other, CreateEvent)
            and self.contract_id == other.contract_id
            and self.payload == other.payload
            and self.signatories == other.signatories
            and self.observers == other.observers
            and self.agreement_text == other.agreement_text
            and self.key == other.key
            and self.created_event_blob == other.created_event_blob
            and self.interface_views == other.interface_views
        )


class ArchiveEvent:
    """
    An event that indicates a contract was archived.
    """

    __slots__ = ("_contract_id",)
    if TYPE_CHECKING:
        _contract_id: ContractId

    def __init__(self, contract_id: ContractId):
        object.__setattr__(self, "_contract_id", contract_id)

    @property
    def contract_id(self) -> ContractId:
        """
        The contract ID of the archived contract.
        """
        return self._contract_id


Event = Union[CreateEvent, ArchiveEvent]


class Boundary:
    """
    An event that indicates a boundary in a query stream where events can be resumed.
    """

    __slots__ = ("_offset",)
    if TYPE_CHECKING:
        _offset: Optional[str]

    def __init__(self, offset: Optional[str]):
        object.__setattr__(self, "_offset", offset)

    @property
    def offset(self) -> Optional[str]:
        """
        The offset at which this boundary occurred.

        If this is ``None``, that indicates that an active contract set was requested, but the
        ledger is completely empty.
        """
        return self._offset

    def __eq__(self, other: Any) -> bool:
        return isinstance(other, Boundary) and self.offset == other.offset

    def __hash__(self):
        return hash(self._offset)

    def __repr__(self):
        return f"Boundary({self._offset!r})"


EventOrBoundary = Union[Event, Boundary]


class ExerciseResponse:
    """
    Returned when directly exercising a choice using :meth:`Connection.create_and_exercise`,
    :meth:`Connection.exercise`, or :meth:`Connection.exercise_by_key`.
    """

    __slots__ = ("_result", "_events")
    if TYPE_CHECKING:
        _result: Optional[Any]
        _events: Sequence[Union[CreateEvent, ArchiveEvent]]

    def __init__(self, result: Optional[Any], events: Sequence[Union[CreateEvent, ArchiveEvent]]):
        object.__setattr__(self, "_result", result)
        object.__setattr__(self, "_events", tuple(events))

    @property
    def result(self) -> Optional[Any]:
        """
        The return value of the choice.
        """
        return self._result

    @property
    def events(self) -> Sequence[Union[CreateEvent, ArchiveEvent]]:
        """
        All of the events that occurred as a result of exercising the choice, including the archive
        event for the contract if the choice is consuming (or otherwise archives it as part of its
        execution).
        """
        return self._events

    def __repr__(self):
        return f"ExerciseResponse(result={self.result}, events={self.events})"


class InterfaceView:
    __slots__ = ("_interface_id", "_view_value")
    if TYPE_CHECKING:
        _interface_id: TypeConName
        _view_value: Any

    def __init__(self, interface_id: TypeConName, view_value: Any):
        object.__setattr__(self, "_interface_id", interface_id)
        object.__setattr__(self, "_view_value", view_value)

    @property
    def interface_id(self) -> TypeConName:
        """
        The interface implemented by the matched event.
        """
        return self._interface_id

    @property
    def view_value(self) -> Any:
        """
        The value of the interface's view method on this event. Set if it was requested in the
        ``InterfaceFilter`` and it could be successfully computed.
        """
        return self._view_value

    def __eq__(self, other: object, /) -> bool:
        return (
            isinstance(other, InterfaceView)
            and self.interface_id == other.interface_id
            and self.view_value == other.view_value
        )


SubmitResponse = Union[None, CreateEvent, ExerciseResponse]


class User:
    """
    Full information about a ``User``.
    """

    __slots__ = ("id", "primary_party", "resource_version", "annotations")
    id: str
    primary_party: Party
    resource_version: Optional[str]
    annotations: Optional[Mapping[str, str]]

    def __init__(
        self,
        id: str,
        primary_party: Party,
        resource_version: Optional[str] = None,
        annotations: Optional[Mapping[str, str]] = None,
    ):
        self.id = id
        self.primary_party = primary_party
        self.resource_version = resource_version
        self.annotations = annotations


class Right(abc.ABC):
    """
    Information about an individual right for a :class:`User`.
    """

    def __setattr__(self, key, value):
        """
        Overridden to make Right objects read-only.
        """
        raise AttributeError


@final
class ReadAs(Right):
    _slots__: Final = ("party",)
    __match_args__: Final = ("party",)

    party: Party

    def __init__(self, party: Party, /):
        object.__setattr__(self, "party", party)

    def __repr__(self) -> str:
        return f"ReadAs({self.party!r})"


@final
class ActAs(Right):
    __slots__: Final = ("party",)
    __match_args__: Final = ("party",)

    party: Party

    def __init__(self, party: Party, /):
        object.__setattr__(self, "party", party)

    def __repr__(self) -> str:
        return f"ActAs({self.party!r})"


@final
class _Admin(Right):
    __slots__: Final = ()
    __match_args__: Final = ()

    def __repr__(self) -> str:
        return "Admin"


Admin = _Admin()


@final
class _IdentityProviderAdmin(Right):
    __slots__: Final = ()
    __match_args__: Final = ()

    def __repr__(self) -> str:
        return "IdentityProviderAdmin"


IdentityProviderAdmin = _IdentityProviderAdmin()


class PartyInfo:
    """
    Full information about a ``Party``.
    """

    __slots__ = ("_party", "_display_name", "_is_local")
    if TYPE_CHECKING:
        _party: Party
        _display_name: str
        _is_local: bool

    def __init__(self, party: Party, display_name: str, is_local: bool):
        object.__setattr__(self, "_party", party)
        object.__setattr__(self, "_display_name", display_name)
        object.__setattr__(self, "_is_local", is_local)

    @property
    def party(self) -> Party:
        """
        The stable unique identifier of a Daml ``Party``.
        """
        return self._party

    @property
    def display_name(self) -> str:
        """
        The human-readable name associated with the ``Party``.
        """
        return self._display_name

    @property
    def is_local(self) -> bool:
        """
        Indicates if the ``Party`` is hosted by the backing participant.
        """
        return self._is_local


class Version:
    __slots__ = ("version", "features")

    version: Final[str]  # type: ignore
    features: Final[VersionFeatures]  # type: ignore

    def __init__(self, version: str, features: VersionFeatures):
        object.__setattr__(self, "version", version)
        object.__setattr__(self, "features", features)


class VersionFeatures:
    __slots__ = ("user_management",)

    user_management: Final[VersionUserManagementFeature]  # type: ignore

    def __init__(self, user_management: VersionUserManagementFeature):
        object.__setattr__(self, "user_management", user_management)


class VersionUserManagementFeature:
    __slots__ = ("supported", "max_rights_per_user", "max_users_page_size")

    supported: Final[bool]  # type: ignore
    max_rights_per_user: Final[int]  # type: ignore
    max_users_page_size: Final[int]  # type: ignore

    def __init__(self, supported: bool, max_rights_per_user: int, max_users_page_size: int):
        object.__setattr__(self, "supported", supported)
        object.__setattr__(self, "max_rights_per_user", max_rights_per_user)
        object.__setattr__(self, "max_users_page_size", max_users_page_size)


class MeteringReport:
    __slots__ = ("participant", "request", "final", "applications")

    participant: str
    request: MeteringReportRequest
    final: bool
    applications: Sequence[MeteringReportApplication]

    def __init__(
        self,
        participant: str,
        request: MeteringReportRequest,
        final: bool,
        applications: Sequence[MeteringReportApplication],
    ):
        object.__setattr__(self, "participant", participant)
        object.__setattr__(self, "request", request)
        object.__setattr__(self, "final", final)
        object.__setattr__(self, "applications", applications)


class MeteringReportRequest:
    __slots__ = ("application", "from_", "to")
    application: str
    from_: datetime
    to: datetime

    def __init__(self, application: str, from_: datetime, to: datetime):
        object.__setattr__(self, "application", application)
        object.__setattr__(self, "from_", from_)
        object.__setattr__(self, "to", to)


class MeteringReportApplication:
    __slots__ = ("application", "events")

    application: str
    events: int

    def __init__(self, application: str, events: int):
        object.__setattr__(self, "application", application)
        object.__setattr__(self, "events", events)


def validate_template_id(value: Union[str, TypeConName]) -> TypeConName:
    if isinstance(value, TypeConName):
        return value
    else:
        return parse_type_con_name(value)



# Copyright (c) 2017-2025 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from ...crypto.v0 import crypto_pb2 as _crypto_pb2
from ..v0 import common_pb2 as _common_pb2
from ..v0 import participant_transaction_pb2 as _participant_transaction_pb2
from ..v0 import quorum_pb2 as _quorum_pb2
from ..v1 import participant_transaction_pb2 as _participant_transaction_pb2_1
from . import common_pb2 as _common_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ViewCommonData(_message.Message):
    __slots__ = ("salt", "informees", "quorums")
    SALT_FIELD_NUMBER: _ClassVar[int]
    INFORMEES_FIELD_NUMBER: _ClassVar[int]
    QUORUMS_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    informees: _containers.RepeatedCompositeFieldContainer[_quorum_pb2.TrustParty]
    quorums: _containers.RepeatedCompositeFieldContainer[_quorum_pb2.Quorum]
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., informees: _Optional[_Iterable[_Union[_quorum_pb2.TrustParty, _Mapping]]] = ..., quorums: _Optional[_Iterable[_Union[_quorum_pb2.Quorum, _Mapping]]] = ...) -> None: ...

class SessionKeyLookup(_message.Message):
    __slots__ = ("session_key_randomness", "fingerprint")
    SESSION_KEY_RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    session_key_randomness: bytes
    fingerprint: str
    def __init__(self, session_key_randomness: _Optional[bytes] = ..., fingerprint: _Optional[str] = ...) -> None: ...

class EncryptedViewMessage(_message.Message):
    __slots__ = ("view_tree", "encryption_scheme", "submitter_participant_signature", "view_hash", "randomness", "session_key_randomness", "domain_id", "view_type")
    VIEW_TREE_FIELD_NUMBER: _ClassVar[int]
    ENCRYPTION_SCHEME_FIELD_NUMBER: _ClassVar[int]
    SUBMITTER_PARTICIPANT_SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    VIEW_HASH_FIELD_NUMBER: _ClassVar[int]
    RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    SESSION_KEY_RANDOMNESS_FIELD_NUMBER: _ClassVar[int]
    DOMAIN_ID_FIELD_NUMBER: _ClassVar[int]
    VIEW_TYPE_FIELD_NUMBER: _ClassVar[int]
    view_tree: bytes
    encryption_scheme: _crypto_pb2.SymmetricKeyScheme
    submitter_participant_signature: _crypto_pb2.Signature
    view_hash: bytes
    randomness: bytes
    session_key_randomness: _containers.RepeatedCompositeFieldContainer[SessionKeyLookup]
    domain_id: str
    view_type: _common_pb2.ViewType
    def __init__(self, view_tree: _Optional[bytes] = ..., encryption_scheme: _Optional[_Union[_crypto_pb2.SymmetricKeyScheme, str]] = ..., submitter_participant_signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., view_hash: _Optional[bytes] = ..., randomness: _Optional[bytes] = ..., session_key_randomness: _Optional[_Iterable[_Union[SessionKeyLookup, _Mapping]]] = ..., domain_id: _Optional[str] = ..., view_type: _Optional[_Union[_common_pb2.ViewType, str]] = ...) -> None: ...

class ViewParticipantData(_message.Message):
    __slots__ = ("salt", "core_inputs", "created_core", "created_in_subview_archived_in_core", "resolved_keys", "action_description", "rollback_context")
    SALT_FIELD_NUMBER: _ClassVar[int]
    CORE_INPUTS_FIELD_NUMBER: _ClassVar[int]
    CREATED_CORE_FIELD_NUMBER: _ClassVar[int]
    CREATED_IN_SUBVIEW_ARCHIVED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
    RESOLVED_KEYS_FIELD_NUMBER: _ClassVar[int]
    ACTION_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ROLLBACK_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    salt: _crypto_pb2.Salt
    core_inputs: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1.InputContract]
    created_core: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2_1.CreatedContract]
    created_in_subview_archived_in_core: _containers.RepeatedScalarFieldContainer[str]
    resolved_keys: _containers.RepeatedCompositeFieldContainer[_participant_transaction_pb2.ViewParticipantData.ResolvedKey]
    action_description: _participant_transaction_pb2_1.ActionDescription
    rollback_context: _participant_transaction_pb2.ViewParticipantData.RollbackContext
    def __init__(self, salt: _Optional[_Union[_crypto_pb2.Salt, _Mapping]] = ..., core_inputs: _Optional[_Iterable[_Union[_participant_transaction_pb2_1.InputContract, _Mapping]]] = ..., created_core: _Optional[_Iterable[_Union[_participant_transaction_pb2_1.CreatedContract, _Mapping]]] = ..., created_in_subview_archived_in_core: _Optional[_Iterable[str]] = ..., resolved_keys: _Optional[_Iterable[_Union[_participant_transaction_pb2.ViewParticipantData.ResolvedKey, _Mapping]]] = ..., action_description: _Optional[_Union[_participant_transaction_pb2_1.ActionDescription, _Mapping]] = ..., rollback_context: _Optional[_Union[_participant_transaction_pb2.ViewParticipantData.RollbackContext, _Mapping]] = ...) -> None: ...

class ActionDescription(_message.Message):
    __slots__ = ("create", "exercise", "fetch", "lookup_by_key")
    class ExerciseActionDescription(_message.Message):
        __slots__ = ("input_contract_id", "choice", "chosen_value", "actors", "by_key", "node_seed", "version", "failed", "interface_id", "template_id")
        INPUT_CONTRACT_ID_FIELD_NUMBER: _ClassVar[int]
        CHOICE_FIELD_NUMBER: _ClassVar[int]
        CHOSEN_VALUE_FIELD_NUMBER: _ClassVar[int]
        ACTORS_FIELD_NUMBER: _ClassVar[int]
        BY_KEY_FIELD_NUMBER: _ClassVar[int]
        NODE_SEED_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        FAILED_FIELD_NUMBER: _ClassVar[int]
        INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
        TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
        input_contract_id: str
        choice: str
        chosen_value: bytes
        actors: _containers.RepeatedScalarFieldContainer[str]
        by_key: bool
        node_seed: bytes
        version: str
        failed: bool
        interface_id: str
        template_id: str
        def __init__(self, input_contract_id: _Optional[str] = ..., choice: _Optional[str] = ..., chosen_value: _Optional[bytes] = ..., actors: _Optional[_Iterable[str]] = ..., by_key: bool = ..., node_seed: _Optional[bytes] = ..., version: _Optional[str] = ..., failed: bool = ..., interface_id: _Optional[str] = ..., template_id: _Optional[str] = ...) -> None: ...
    CREATE_FIELD_NUMBER: _ClassVar[int]
    EXERCISE_FIELD_NUMBER: _ClassVar[int]
    FETCH_FIELD_NUMBER: _ClassVar[int]
    LOOKUP_BY_KEY_FIELD_NUMBER: _ClassVar[int]
    create: _participant_transaction_pb2.ActionDescription.CreateActionDescription
    exercise: ActionDescription.ExerciseActionDescription
    fetch: _participant_transaction_pb2.ActionDescription.FetchActionDescription
    lookup_by_key: _participant_transaction_pb2.ActionDescription.LookupByKeyActionDescription
    def __init__(self, create: _Optional[_Union[_participant_transaction_pb2.ActionDescription.CreateActionDescription, _Mapping]] = ..., exercise: _Optional[_Union[ActionDescription.ExerciseActionDescription, _Mapping]] = ..., fetch: _Optional[_Union[_participant_transaction_pb2.ActionDescription.FetchActionDescription, _Mapping]] = ..., lookup_by_key: _Optional[_Union[_participant_transaction_pb2.ActionDescription.LookupByKeyActionDescription, _Mapping]] = ...) -> None: ...

class CreatedContract(_message.Message):
    __slots__ = ("contract", "consumed_in_core", "rolled_back")
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    CONSUMED_IN_CORE_FIELD_NUMBER: _ClassVar[int]
    ROLLED_BACK_FIELD_NUMBER: _ClassVar[int]
    contract: _common_pb2_1.SerializableContract
    consumed_in_core: bool
    rolled_back: bool
    def __init__(self, contract: _Optional[_Union[_common_pb2_1.SerializableContract, _Mapping]] = ..., consumed_in_core: bool = ..., rolled_back: bool = ...) -> None: ...

class InputContract(_message.Message):
    __slots__ = ("contract", "consumed")
    CONTRACT_FIELD_NUMBER: _ClassVar[int]
    CONSUMED_FIELD_NUMBER: _ClassVar[int]
    contract: _common_pb2_1.SerializableContract
    consumed: bool
    def __init__(self, contract: _Optional[_Union[_common_pb2_1.SerializableContract, _Mapping]] = ..., consumed: bool = ...) -> None: ...
